@@ -12,11 +12,11 @@ Map::Tube::Node - Defines the node for Map::Tube!
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 Readonly my $BAKERLOO => { 'Harrow & Wealdstone' => 'B1',
                            'Kenton'              => 'B2',
@@ -31,12 +31,12 @@ Readonly my $BAKERLOO => { 'Harrow & Wealdstone' => 'B1',
 						   'Kilburn Park'        => 'B11',
 						   'Maida Vale'          => 'B12',
 						   'Warwick Avenue'      => 'B13',
-						   'Paddington'          => 'B14',
-						   'Edgware Road'        => 'B15',
+						   'Paddington'          => 'PDG', # Special case
+						   'Edgware Road'        => 'EDG',
 						   'Marleybone'          => 'B16',
-						   'Baker Street'        => 'BS1',  # Special case
+						   'Baker Street'        => 'BST', # Special case
 						   q{Regent's Park}      => 'B18',
-						   'Oxford Circus'       => 'OX1',
+						   'Oxford Circus'       => 'OXC', # Special case
 						   'Piccadilly Circus'   => 'B20',
 						   'Charing Cross'       => 'B21',
 						   'Embankment'          => 'B22',
@@ -51,19 +51,19 @@ Readonly my $CENTRAL => { 'West Ruislip'           => 'C1',
 						  'Greenford'              => 'C5',
 						  'Perivale'               => 'C6',
 						  'Hanger Lane'            => 'C7',
-						  'North Acton'            => 'NA1', # Special case
+						  'North Acton'            => 'NAC', # Special case
 						  'Ealing Broadway'        => 'C9',
 						  'West Acton'             => 'C10',
 						  'East Acton'             => 'C11',
-						  'White City'             => 'C12',
+						  'White City'             => 'WTC',
 						  q{Shepherd's Bush}       => 'C13',
 						  'Holland Park'           => 'C14',
-						  'Notting Hill Gate'      => 'C15',
+						  'Notting Hill Gate'      => 'NHG', # Special case
 						  'Queensway'              => 'C16',
 						  'Lancaster Gate'         => 'C17',
 						  'Marble Arch'            => 'C18',
-						  'Bond Street'            => 'BO1', # Special case
-						  'Oxfod Circus'           => 'OX1', # Special case
+						  'Bond Street'            => 'BOS', # Special case
+						  'Oxfod Circus'           => 'OXC', # Special case
 						  'Tottenham Court Road'   => 'C21',
 						  'Holborn'                => 'C22',
 						  'Chancery Lane'          => 'C23',
@@ -76,7 +76,7 @@ Readonly my $CENTRAL => { 'West Ruislip'           => 'C1',
 						  'Mile End'               => 'C30',
 						  'Stratford'              => 'C31',
 						  'Leyton'                 => 'C32',
-						  'Leytonstone'            => 'LE1', # Special case
+						  'Leytonstone'            => 'LES', # Special case
 						  'Wanstead'               => 'C34',
 						  'Redbridge'              => 'C35',
 						  'Gants Hill'             => 'C36',
@@ -89,12 +89,51 @@ Readonly my $CENTRAL => { 'West Ruislip'           => 'C1',
 						  'Snaresbrook'            => 'C42',
 						  'South Woodford'         => 'C43',
 						  'Woodford'               => 'C44',
-						  'Buckhurst Hill'         => 'BH1', # Special case
+						  'Buckhurst Hill'         => 'BHH', # Special case
 						  'Loughton'               => 'C46',
 						  'Debden'                 => 'C47',
 						  'Theydon Bois'           => 'C48',
 						  'Epping'                 => 'C49' };
 						   
+Readonly my $CIRCLE => { 'Edgware Road'              => 'EDG', # Special case
+						 'Bayswater'                 => 'BYW', # Special case
+						 'Notting Hill Gate'         => 'NHG', # Special case
+						 'High Street Kensington'    => 'HSK', # Special case
+						 'Gloucester Road',          => 'GLS', # Special case
+						 'South Kensington'          => 'SKN', # Special case
+						 'Sloane Square'             => 'SLQ', # Special case
+						 'Victoria'                  => 'VCT', # Special case
+						 q{St. James's Park}         => 'SJP', # Special case
+						 'Westminster'               => 'WMN', # Special case
+						 'Embankment'                => 'EBK', # Special case
+						 'Temple'                    => 'TMP', # Special case
+						 'Blackfriars'               => 'BLF', # Special case
+						 'Mansion House'             => 'MSH', # Special case
+						 'Cannon Street'             => 'CNS', # Special case
+						 'Monument'                  => 'MMT', # Special case
+						 'Tower Hill'                => 'THL', # Special case
+						 'Aldgate'                   => 'AGT', # Special case
+						 'Liverpool Street'          => 'LST', # Speical case
+						 'Moorgate'                  => 'MGT', # Special case
+						 'Barbican'                  => 'BBC', # Special case
+						 'Farringdon'                => 'FRG', # Special case
+						 q{King's cross St. Pancras} => 'KCS', # Special case
+						 'Euston Square'             => 'ESQ', # Special case
+						 'Great Portland Street'     => 'GPS', # Special case
+						 'Baker Street'              => 'BST', # Special case
+						 'Edgware Road'              => 'EDG', # Special case
+						 'Paddington'                => 'PDG', # Special case
+						 'Royal Oak'                 => 'RYL', # Special case
+						 'Westbourne Park'           => 'WBP', # Special case
+						 'Ladbroke Grove'            => 'LBG', # Special case
+						 'Latimer Road'              => 'LTR', # Special case
+						 'White City'                => 'WTC', # Special case
+						 'Wood Lane'                 => 'WDL', # Special case
+						 q{Shepherd's Bush Market}   => 'SBM', # Special case
+						 'Goldhawk Road'             => 'GHR', # Special case
+						 'Hammersmith'               => 'HSM'  # Special case 
+						};
+						   
 Readonly my $JUBILEE => { 'Stanmore'         => 'J1',
 					      'Canons Park'      => 'J2',
 						  'Queensbury'       => 'J3',
@@ -108,10 +147,10 @@ Readonly my $JUBILEE => { 'Stanmore'         => 'J1',
 						  'Finchley Road'    => 'J11',
 						  'Swiss Cottage'    => 'J12',
 						  q{St. John's Wood} => 'J13',
-						  'Baker Street'     => 'BS1',
-						  'Bond Street'      => 'BO1',
-						  'Green Park'       => 'GP1',
-						  'Westminster'      => 'J17',
+						  'Baker Street'     => 'BST', # Special case
+						  'Bond Street'      => 'BOS', # Special case
+						  'Green Park'       => 'GPK',
+						  'Westminster'      => 'WMN',
 						  'Waterloo'         => 'J18',
 						  'Southwark'        => 'J19',
 						  'London Bridge'    => 'J20',
@@ -127,12 +166,12 @@ Readonly my $VICTORIA => { 'Brixton'                   => 'V1',
 						   'Stockwell'                 => 'V2',
 						   'Vauxhall'                  => 'V3',
 						   'Pimlico'                   => 'V4',
-						   'Victoria'                  => 'V5',
-						   'Green Park'                => 'GP1',  # Special case
-						   'Oxford Circus'             => 'OX1',  # Special case
+						   'Victoria'                  => 'VCT',
+						   'Green Park'                => 'GPK', # Special case
+						   'Oxford Circus'             => 'OXC', # Special case
 						   'Warren Street'             => 'V8',
 						   'Euston'                    => 'V9',
-						   q{King's Cross St. Pancras} => 'V10',
+						   q{King's Cross St. Pancras} => 'KCS',
 						   'Highbury & Islington'      => 'V11',
 						   'Finsbury Park'             => 'V12',
 						   'Seven Sisters'             => 'V13',
@@ -193,12 +232,10 @@ sub init {
 		'B10' => ['B9','B11'],
 		'B11' => ['B10','B12'],
 		'B12' => ['B11','B13'],
-		'B13' => ['B12','B14'],
-		'B14' => ['B13','B15'],
-		'B15' => ['B14','B16'],
-		'B16' => ['BS1','B15'],
-		'B18' => ['BS1','OX1'],
-		'B20' => ['OX1','B21'],
+		'B13' => ['B12','PDG'],
+		'B16' => ['BST','EDG'],
+		'B18' => ['BST','OXC'],
+		'B20' => ['OXC','B21'],
 		'B21' => ['B20','B22'],
 		'B22' => ['B21','B23'],		
 		'B23' => ['B22','B24'],
@@ -212,18 +249,16 @@ sub init {
 		'C4'  => ['C3','C5'],
 		'C5'  => ['C4','C6'],
 		'C6'  => ['C5','C7'],
-		'C7'  => ['C6','NA1'],
-		'C9'  => ['NA1','C10'],
+		'C7'  => ['C6','NAC'],
+		'C9'  => ['NAC','C10'],
 		'C10' => ['C9','C11'],
-		'C11' => ['C10','C12'],
-		'C12' => ['C11','C13'],
-		'C13' => ['C12','C14'],
-		'C14' => ['C13','C15'],
-		'C15' => ['C14','C16'],
-		'C16' => ['C15','C17'],
+		'C11' => ['C10','WTC'],
+		'C13' => ['WTC','C14'],
+		'C14' => ['C13','NHG'],
+		'C16' => ['NHG','C17'],
 		'C17' => ['C16','C18'],
-		'C18' => ['C17','BO1'],
-		'C21' => ['OX1','C22'],
+		'C18' => ['C17','BOS'],
+		'C21' => ['OXC','C22'],
 		'C22' => ['C21','C23'],
 		'C23' => ['C22','C24'],
 		'C24' => ['C23','C25'],
@@ -234,23 +269,51 @@ sub init {
 		'C29' => ['C28','C30'],
 		'C30' => ['C29','C31'],
 		'C31' => ['C30','C32'],
-		'C32' => ['C31','LE1'],
-		'C34' => ['LE1','C35'],
+		'C32' => ['C31','LES'],
+		'C34' => ['LES','C35'],
 		'C35' => ['C34','C36'],
 		'C36' => ['C35','C37'],
 		'C37' => ['C36','C38'],
 		'C38' => ['C37','C39'],
 		'C39' => ['C38','C40'],
 		'C40' => ['C39','C41'],
-		'C41' => ['C40','BH1'],
-		'C42' => ['LE1','C43'],
+		'C41' => ['C40','BHH'],
+		'C42' => ['LES','C43'],
 		'C43' => ['C43','C44'],
-		'C44' => ['BH1','C43'],
-		'C46' => ['BH1','C47'],
+		'C44' => ['BHH','C43'],
+		'C46' => ['BHH','C47'],
 		'C47' => ['C46','C48'],
 		'C48' => ['C47','C49'],
 		'C49' => ['C48'],
 		
+		## CIRCLE
+		'HSM' => ['GHR'],
+		'GHR' => ['HSM','SBM'],
+		'SBM' => ['GHR','WDL'],
+		'WDL' => ['WTC','SBM'],
+		'LTR' => ['WTC','LBG'],
+		'LBG' => ['LTR','WBP'],
+		'WBP' => ['LBG','RYL'],
+		'RYL' => ['WBP','PDG'],
+		'GPS' => ['BST','ESQ'],
+		'FRG' => ['KCS','BBC'],
+		'BBC' => ['FRG','MGT'],
+		'MGT' => ['LST','BBC'],
+		'LST' => ['MGT','AGT'],
+		'AGT' => ['LST','THL'],
+		'THL' => ['AGT','MMT'],
+		'MMT' => ['THL','CNS'],
+		'CNS' => ['MMT','MSH'],
+		'MSH' => ['CNS','BLF'],
+		'BLF' => ['TMP','MSH'],
+		'TMP' => ['BLF','EBK'],
+		'SJP' => ['WMN','EBK'],
+		'SLQ' => ['VCT','SKN'],
+		'SKN' => ['SLQ','GLS'],
+		'GLS' => ['SKN','HSK'],
+		'HSK' => ['GLS','NHG'],
+		'BYW' => ['NHG','EDG'],
+		
 		## JUBILEE
 		'J1'  => ['J2'],
 		'J2'  => ['J1','J3'],
@@ -265,9 +328,8 @@ sub init {
 		'J11' => ['J10','J12'],
 		'J12' => ['J11','J13'],
 		'J13' => ['J12','J14'],
-		'J14' => ['J13','BO1'],
-		'J17' => ['GP1','J18'],
-		'J18' => ['J17','J19'],
+		'J14' => ['J13','BOS'],
+		'J18' => ['WMN','J19'],
 		'J19' => ['J18','J20'],
 		'J20' => ['J19','J21'],
 		'J21' => ['J20','J22'],
@@ -282,12 +344,10 @@ sub init {
 		'V1'  => ['V2'],
 		'V2'  => ['V1','V3'],
 		'V3'  => ['V2','V4'],
-		'V4'  => ['V3','V5'],
-		'V5'  => ['V4','GP1'],
-		'V8'  => ['OX1','V9'],
-		'V9'  => ['V8','V10'],
-		'V10' => ['V9','V11'],
-		'V11' => ['V10','V12'],
+		'V4'  => ['V3','VCT'],
+		'V8'  => ['OXC','V9'],
+		'V9'  => ['V8','KCS'],
+		'V11' => ['KCS','V12'],
 		'V12' => ['V11','V13'],
 		'V13' => ['V12','V14'],
 		'V14' => ['V13','V15'],
@@ -296,13 +356,20 @@ sub init {
 		'V17' => ['V16'],
 		
 		## Special case
-		'BS1' => ['BO1','B18','B16'],		
-		'GP1' => ['V5','OX1','BO1','J17'],		
-		'BO1' => ['GP1','BS1','OX1','C18'],
-		'OX1' => ['V6','V8','BO1','B18','B20','C21'],
-		'NA1' => ['C7','C10','C11'],
-		'LE1' => ['C32','C34','C42'],
-		'BH1' => ['C41','C44'],
+		'BST' => ['BOS','B18','B16','GPS'],		
+		'GPK' => ['VCT','OXC','BOS1','WMN'],		
+		'BOS' => ['GPK','BST','OXC','C18'],
+		'OXC' => ['V6','V8','BOS','B18','B20','C21'],
+		'NAC' => ['C7','C10','C11'],
+		'LES' => ['C32','C34','C42'],
+		'BHH' => ['C41','C44'],
+		'NHG' => ['C14','C16','R2','R4'],
+		'VCT' => ['V4','GPK','R7','SJP'],
+		'WMN' => ['SJP','GPK','J18','EBK'],
+		'PDG' => ['B13','EDG','RYL'],
+		'WTC' => ['C11','C13','LTR','WDL','C13'],
+		'EDG' => ['PDG','B16'],
+		'KCS' => ['V9','V11','EUS','FRG'],		
 	};
 	return $node;
 }
@@ -313,7 +380,7 @@ sub init {
 
 sub load_element
 {
-	return {%{$BAKERLOO}, %{$CENTRAL}, %{$VICTORIA}, %{$JUBILEE}};
+	return {%{$BAKERLOO}, %{$CENTRAL}, %{$CIRCLE}, %{$VICTORIA}, %{$JUBILEE}};
 }
 
 =head1 AUTHOR
